/**
 * Circle
 * 
 * This is GPL'd code
 * (c) by Patrick Kilian 2003
 *
 * Eine Klasse, die die x- und y- Koordinate des Mittelpunkt und den Radius
 * eines Kreises speichert.
 * Achtung es findet _keine_ Fehlerbehandlung statt.
 *
 * @author Patrick Kilian
 * @version 0.01
 */
public class Circle {
    // x-Koordinate des Mittelpunktes
    private double x_koord = 0;
    // y-Koordinate des Mittelpunkte
    private double y_koord = 0;
    // Der positive Radius des Kreises
    private double radius = 1;
    /**
     * Konstruktor der Klasse Kreis.
     * Keine Aufrufsparameter bedeutet x = y = 0; r = 1
     */
    public Circle() {
        return;
    }
    /**
     * Konstruktor der Klasse Kreis.
     * @param x x-Koordinate des Mittelpunktes
     * @param y y-Koordinate des Mittelpunktes
     * @param r der Radius darf nicht negativ sein
     */
    public Circle(double x, double y, double r) {
        x_koord = x;
        y_koord = y;
        if ( r >= 0 ) {
            radius = r;
        }
    }
    /**
     * Setzt den Mittelpunkt auf die angegebenen Werte
     * @param x x-Koordinate
     * @param y y-Koordinate
     * 
     * Achtung es findet _keine_ Fehlerbehandlung statt.
     */
    public void setCenter(double x, double y) {
        x_koord = x;
        y_koord = y;
    }
    /**
     * Gibt die x-Koordinate aus
     * @return x-Koordinate
     */
    public double getCenterX() {
        return (x_koord);
    }
    /**
     * Gibt die y-Koordinate aus
     * @return y-Koordinate
     */
    public double getCenterY() {
        return (y_koord);
    }
    /**
     * Setzt die x-Koordinate des Mittelpunkt auf den angegebenen Wert
     * @param x x-Koordinate
     *
     * Achtung es findet _keine_ Fehlerbehandlung statt.
     */
    public void setCenterX(double x) {
        x_koord = x;
    }
    /**
     * Setzt die y-Koordinate des Mittelpunkt auf den angegebenen Wert
     * @param y y-Koordinate
     *
     * Achtung es findet _keine_ Fehlerbehandlung statt.
     */
    public void setCenterY(double y) {
        y_koord = y;
    }
    /**
     * Gibt den Radius aus
     * @return Radius des Kreises
     */
    public double getRadius() {
        return (radius);
    }
    /**
     * Setzt den Radius auf den angebenen Wert
     * @param r nicht negativer Radius des Kreises
     */
    public void setRadius(double r) {
        if (r >= 0) {
            radius = r;
        }
    }
    /**
     * Gibt die Flche des Kreises aus
     * @return Flche
     */
    public double area() {
        return (Math.PI * radius * radius);
    }
    /**
     * Gibt Umfang des Kreises aus
     * @return Umfang
     */
    public double circumference() {
        return (Math.PI * radius * 2);
    }
    /**
     * Gibt eine Stringdarstellung des Kreises aus
     * @return String der den Kreis beschreibt
     */
    public String toString() {
        String out = new String("Circle(");
        out += x_koord;
        out += ",";
        out += y_koord;
        out += ",";
        out += radius;
        out += ")";
        return (out);
    }
}
